summaryrefslogtreecommitdiffstats
path: root/test
diff options
context:
space:
mode:
authorQuincey Koziol <koziol@hdfgroup.org>2002-09-13 16:57:46 (GMT)
committerQuincey Koziol <koziol@hdfgroup.org>2002-09-13 16:57:46 (GMT)
commit12f8879c407478ab7cb7c60e1c37554cf370c175 (patch)
tree87198e8ca2084f756e91827e35c4d438b8a92011 /test
parent18758623d78ff9fbd4880761da6d40fdfe44c945 (diff)
downloadhdf5-12f8879c407478ab7cb7c60e1c37554cf370c175.zip
hdf5-12f8879c407478ab7cb7c60e1c37554cf370c175.tar.gz
hdf5-12f8879c407478ab7cb7c60e1c37554cf370c175.tar.bz2
[svn-r5926] Purpose:
API name change Description: Change all "space time" references to "alloc time", including API functions and macro definitions, etc. Platforms tested: FreeBSD 4.6 (sleipnir) w/C++ Solaris 2.7 (arabica) w/FORTRAN IRIX64 6.5 (modi4) w/parallel & FORTRAN
Diffstat (limited to 'test')
-rw-r--r--test/dsets.c4
-rw-r--r--test/fillval.c38
-rw-r--r--test/tmisc.c48
3 files changed, 45 insertions, 45 deletions
diff --git a/test/dsets.c b/test/dsets.c
index be52ed2..7442c50 100644
--- a/test/dsets.c
+++ b/test/dsets.c
@@ -167,7 +167,7 @@ test_create(hid_t file)
assert(create_parms >= 0);
status = H5Pset_layout(create_parms, H5D_COMPACT);
assert(status >= 0);
- status = H5Pset_space_time(create_parms, H5D_SPACE_ALLOC_EARLY);
+ status = H5Pset_alloc_time(create_parms, H5D_ALLOC_TIME_EARLY);
assert(status >= 0);
dataset = H5Dcreate(file, DSET_COMPACT_NAME, H5T_NATIVE_DOUBLE,
@@ -318,7 +318,7 @@ test_compact_io(void)
assert(plist >= 0);
status = H5Pset_layout(plist, H5D_COMPACT);
assert(status >= 0);
- status = H5Pset_space_time(plist, H5D_SPACE_ALLOC_EARLY);
+ status = H5Pset_alloc_time(plist, H5D_ALLOC_TIME_EARLY);
assert(status >= 0);
/* Create and write to a compact dataset */
diff --git a/test/tmisc.c b/test/tmisc.c
index 1e1e613..da31f43 100644
--- a/test/tmisc.c
+++ b/test/tmisc.c
@@ -1124,8 +1124,8 @@ test_misc8(void)
CHECK(ret, FAIL, "H5Pset_layout");
/* Set the space allocation time to early */
- ret = H5Pset_space_time(dcpl,H5D_SPACE_ALLOC_EARLY);
- CHECK(ret, FAIL, "H5Pset_space_time");
+ ret = H5Pset_alloc_time(dcpl,H5D_ALLOC_TIME_EARLY);
+ CHECK(ret, FAIL, "H5Pset_alloc_time");
/* Create a contiguous dataset, with space allocation early */
did = H5Dcreate(fid, MISC8_DSETNAME1, H5T_NATIVE_INT, sid, dcpl);
@@ -1142,8 +1142,8 @@ test_misc8(void)
#ifndef H5_HAVE_PARALLEL
/* Set the space allocation time to late */
- ret = H5Pset_space_time(dcpl,H5D_SPACE_ALLOC_LATE);
- CHECK(ret, FAIL, "H5Pset_space_time");
+ ret = H5Pset_alloc_time(dcpl,H5D_ALLOC_TIME_LATE);
+ CHECK(ret, FAIL, "H5Pset_alloc_time");
/* Create a contiguous dataset, with space allocation late */
did = H5Dcreate(fid, MISC8_DSETNAME2, H5T_NATIVE_INT, sid, dcpl);
@@ -1167,8 +1167,8 @@ test_misc8(void)
CHECK(ret, FAIL, "H5Dclose");
/* Set the space allocation time to incremental */
- ret = H5Pset_space_time(dcpl,H5D_SPACE_ALLOC_INCR);
- CHECK(ret, FAIL, "H5Pset_space_time");
+ ret = H5Pset_alloc_time(dcpl,H5D_ALLOC_TIME_INCR);
+ CHECK(ret, FAIL, "H5Pset_alloc_time");
/* Create a contiguous dataset, with space allocation late */
did = H5Dcreate(fid, MISC8_DSETNAME3, H5T_NATIVE_INT, sid, dcpl);
@@ -1197,8 +1197,8 @@ test_misc8(void)
CHECK(ret, FAIL, "H5Pset_layout");
/* Set the space allocation time to late */
- ret = H5Pset_space_time(dcpl,H5D_SPACE_ALLOC_LATE);
- CHECK(ret, FAIL, "H5Pset_space_time");
+ ret = H5Pset_alloc_time(dcpl,H5D_ALLOC_TIME_LATE);
+ CHECK(ret, FAIL, "H5Pset_alloc_time");
/* Create a contiguous dataset, with space allocation late */
/* Should fail */
@@ -1206,8 +1206,8 @@ test_misc8(void)
VERIFY(did, FAIL, "H5Dcreate");
/* Set the space allocation time to incremental */
- ret = H5Pset_space_time(dcpl,H5D_SPACE_ALLOC_INCR);
- CHECK(ret, FAIL, "H5Pset_space_time");
+ ret = H5Pset_alloc_time(dcpl,H5D_ALLOC_TIME_INCR);
+ CHECK(ret, FAIL, "H5Pset_alloc_time");
/* Create a contiguous dataset, with space allocation incremental */
/* Should fail */
@@ -1215,8 +1215,8 @@ test_misc8(void)
VERIFY(did, FAIL, "H5Dcreate");
/* Set the space allocation time to early */
- ret = H5Pset_space_time(dcpl,H5D_SPACE_ALLOC_EARLY);
- CHECK(ret, FAIL, "H5Pset_space_time");
+ ret = H5Pset_alloc_time(dcpl,H5D_ALLOC_TIME_EARLY);
+ CHECK(ret, FAIL, "H5Pset_alloc_time");
/* Create a contiguous dataset, with space allocation early */
did = H5Dcreate(fid, MISC8_DSETNAME4, H5T_NATIVE_INT, sid, dcpl);
@@ -1238,8 +1238,8 @@ test_misc8(void)
CHECK(ret, FAIL, "H5Pset_layout");
/* Set the space allocation time to early */
- ret = H5Pset_space_time(dcpl,H5D_SPACE_ALLOC_EARLY);
- CHECK(ret, FAIL, "H5Pset_space_time");
+ ret = H5Pset_alloc_time(dcpl,H5D_ALLOC_TIME_EARLY);
+ CHECK(ret, FAIL, "H5Pset_alloc_time");
/* Use chunked storage for this dataset */
ret = H5Pset_chunk(dcpl,rank,chunk_dims);
@@ -1260,8 +1260,8 @@ test_misc8(void)
#ifndef H5_HAVE_PARALLEL
/* Set the space allocation time to late */
- ret = H5Pset_space_time(dcpl,H5D_SPACE_ALLOC_LATE);
- CHECK(ret, FAIL, "H5Pset_space_time");
+ ret = H5Pset_alloc_time(dcpl,H5D_ALLOC_TIME_LATE);
+ CHECK(ret, FAIL, "H5Pset_alloc_time");
/* Use chunked storage for this dataset */
ret = H5Pset_chunk(dcpl,rank,chunk_dims);
@@ -1289,8 +1289,8 @@ test_misc8(void)
CHECK(ret, FAIL, "H5Dclose");
/* Set the space allocation time to incremental */
- ret = H5Pset_space_time(dcpl,H5D_SPACE_ALLOC_INCR);
- CHECK(ret, FAIL, "H5Pset_space_time");
+ ret = H5Pset_alloc_time(dcpl,H5D_ALLOC_TIME_INCR);
+ CHECK(ret, FAIL, "H5Pset_alloc_time");
/* Create a chunked dataset, with space allocation incremental */
did = H5Dcreate(fid, MISC8_DSETNAME7, H5T_NATIVE_INT, sid, dcpl);
@@ -1339,8 +1339,8 @@ test_misc8(void)
#endif /* H5_HAVE_PARALLEL */
/* Set the space allocation time to early */
- ret = H5Pset_space_time(dcpl,H5D_SPACE_ALLOC_EARLY);
- CHECK(ret, FAIL, "H5Pset_space_time");
+ ret = H5Pset_alloc_time(dcpl,H5D_ALLOC_TIME_EARLY);
+ CHECK(ret, FAIL, "H5Pset_alloc_time");
/* Use compression as well as chunking for these datasets */
#ifdef H5_HAVE_COMPRESSION
@@ -1377,8 +1377,8 @@ test_misc8(void)
#ifndef H5_HAVE_PARALLEL
/* Set the space allocation time to late */
- ret = H5Pset_space_time(dcpl,H5D_SPACE_ALLOC_LATE);
- CHECK(ret, FAIL, "H5Pset_space_time");
+ ret = H5Pset_alloc_time(dcpl,H5D_ALLOC_TIME_LATE);
+ CHECK(ret, FAIL, "H5Pset_alloc_time");
/* Create a chunked dataset, with space allocation late */
did = H5Dcreate(fid, MISC8_DSETNAME9, H5T_NATIVE_INT, sid, dcpl);
@@ -1447,8 +1447,8 @@ test_misc8(void)
CHECK(ret, FAIL, "H5Dclose");
/* Set the space allocation time to incremental */
- ret = H5Pset_space_time(dcpl,H5D_SPACE_ALLOC_INCR);
- CHECK(ret, FAIL, "H5Pset_space_time");
+ ret = H5Pset_alloc_time(dcpl,H5D_ALLOC_TIME_INCR);
+ CHECK(ret, FAIL, "H5Pset_alloc_time");
/* Create a chunked dataset, with space allocation incremental */
did = H5Dcreate(fid, MISC8_DSETNAME10, H5T_NATIVE_INT, sid, dcpl);
diff --git a/test/fillval.c b/test/fillval.c
index fd63464..8f8dcaf 100644
--- a/test/fillval.c
+++ b/test/fillval.c
@@ -234,7 +234,7 @@ test_create(hid_t fapl, const char *base_name, H5D_layout_t layout)
long rd_l, fill_l = 0x4321;
char filename[1024];
H5D_space_status_t allocation;
- H5D_space_time_t alloc_time;
+ H5D_alloc_time_t alloc_time;
H5D_fill_time_t fill_time;
comp_datatype rd_c, fill_ctype;
@@ -266,7 +266,7 @@ test_create(hid_t fapl, const char *base_name, H5D_layout_t layout)
/* I. Test cases for late space allocation except compact dataset */
if(H5D_COMPACT!=layout) {
- if(H5Pset_space_time(dcpl, H5D_SPACE_ALLOC_LATE) < 0) goto error;
+ if(H5Pset_alloc_time(dcpl, H5D_ALLOC_TIME_LATE) < 0) goto error;
if(H5Pset_fill_time(dcpl, H5D_FILL_TIME_ALLOC) < 0) goto error;
/* 1. Compound datatype test */
@@ -325,7 +325,7 @@ test_create(hid_t fapl, const char *base_name, H5D_layout_t layout)
} else if (H5D_COMPACT==layout) {
if (H5Pset_layout(dcpl, H5D_COMPACT)<0) goto error;
}
- if(H5Pset_space_time(dcpl, H5D_SPACE_ALLOC_EARLY) < 0) goto error;
+ if(H5Pset_alloc_time(dcpl, H5D_ALLOC_TIME_EARLY) < 0) goto error;
/* 1. Compound datatype test */
if(H5Pget_fill_value(dcpl, comp_type_id, &fill_ctype)<0) goto error;
@@ -418,11 +418,11 @@ test_create(hid_t fapl, const char *base_name, H5D_layout_t layout)
goto error;
}
#endif
- if(H5Pget_space_time(dcpl, &alloc_time)<0) goto error;
+ if(H5Pget_alloc_time(dcpl, &alloc_time)<0) goto error;
if(H5Pget_fill_time(dcpl, &fill_time)<0) goto error;
- if(alloc_time != H5D_SPACE_ALLOC_LATE) {
+ if(alloc_time != H5D_ALLOC_TIME_LATE) {
H5_FAILED();
- puts(" Got non-H5D_SPACE_ALLOC_LATE space allocation time.");
+ puts(" Got non-H5D_ALLOC_TIME_LATE space allocation time.");
printf(" Got %d\n", alloc_time);
}
if(fill_time != H5D_FILL_TIME_ALLOC) {
@@ -443,11 +443,11 @@ test_create(hid_t fapl, const char *base_name, H5D_layout_t layout)
goto error;
}
if ((dcpl=H5Dget_create_plist(dset4))<0) goto error;
- if(H5Pget_space_time(dcpl, &alloc_time)<0) goto error;
+ if(H5Pget_alloc_time(dcpl, &alloc_time)<0) goto error;
if(H5Pget_fill_time(dcpl, &fill_time)<0) goto error;
- if(alloc_time != H5D_SPACE_ALLOC_LATE) {
+ if(alloc_time != H5D_ALLOC_TIME_LATE) {
H5_FAILED();
- puts(" Got non-H5D_SPACE_ALLOC_LATE space allocation time.");
+ puts(" Got non-H5D_ALLOC_TIME_LATE space allocation time.");
printf(" Got %d\n", alloc_time);
}
if(fill_time != H5D_FILL_TIME_NEVER) {
@@ -484,10 +484,10 @@ test_create(hid_t fapl, const char *base_name, H5D_layout_t layout)
printf(" Got %d\n", allocation);
goto error;
}
- if(H5Pget_space_time(dcpl, &alloc_time)<0) goto error;
- if(alloc_time != H5D_SPACE_ALLOC_EARLY) {
+ if(H5Pget_alloc_time(dcpl, &alloc_time)<0) goto error;
+ if(alloc_time != H5D_ALLOC_TIME_EARLY) {
H5_FAILED();
- puts(" Got non-H5D_SPACE_ALLOC_EARLY space allocation time.");
+ puts(" Got non-H5D_ALLOC_TIME_EARLY space allocation time.");
printf(" Got %d\n", alloc_time);
}
if(H5Pget_fill_time(dcpl, &fill_time)<0) goto error;
@@ -516,10 +516,10 @@ test_create(hid_t fapl, const char *base_name, H5D_layout_t layout)
printf(" Got %ld, set %ld\n", rd_l, fill_l);
goto error;
}
- if(H5Pget_space_time(dcpl, &alloc_time)<0) goto error;
- if(alloc_time != H5D_SPACE_ALLOC_EARLY) {
+ if(H5Pget_alloc_time(dcpl, &alloc_time)<0) goto error;
+ if(alloc_time != H5D_ALLOC_TIME_EARLY) {
H5_FAILED();
- puts(" Got non-H5D_SPACE_ALLOC_EARLY space allocation time.");
+ puts(" Got non-H5D_ALLOC_TIME_EARLY space allocation time.");
printf(" Got %d\n", alloc_time);
}
if(H5Pget_fill_time(dcpl, &fill_time)<0) goto error;
@@ -878,9 +878,9 @@ test_rdwr(hid_t fapl, const char *base_name, H5D_layout_t layout)
if ((ctype_id=create_compound_type())<0) goto error;
/* I. Test H5D_SPACE_ALLOC_LATE space allocation cases */
if(H5D_COMPACT != layout) {
- if(H5Pset_space_time(dcpl, H5D_SPACE_ALLOC_LATE) < 0) goto error;
+ if(H5Pset_alloc_time(dcpl, H5D_ALLOC_TIME_LATE) < 0) goto error;
/* case for H5D_FILL_TIME_ALLOC as fill write time and fill value to be default */
if(H5Pset_fill_time(dcpl, H5D_FILL_TIME_ALLOC) < 0) goto error;
@@ -931,8 +931,8 @@ test_rdwr(hid_t fapl, const char *base_name, H5D_layout_t layout)
}
- /* II. Test H5D_SPACE_ALLOC_EARLY space allocation cases */
- if(H5Pset_space_time(dcpl, H5D_SPACE_ALLOC_EARLY) < 0) goto error;
+ /* II. Test H5D_ALLOC_TIME_EARLY space allocation cases */
+ if(H5Pset_alloc_time(dcpl, H5D_ALLOC_TIME_EARLY) < 0) goto error;
/* case for H5D_FILL_TIME_ALLOC as fill write time and fill value to be default */
if(H5Pset_fill_time(dcpl, H5D_FILL_TIME_ALLOC) < 0) goto error;
@@ -878,9 +878,9 @@ test_rdwr(hid_t fapl, const char *base_name, H5D_layout_t layout)
if ((ctype_id=create_compound_type())<0) goto error;
- /* I. Test H5D_SPACE_ALLOC_LATE space allocation cases */
+ /* I. Test H5D_ALLOC_TIME_LATE space allocation cases */
if(H5D_COMPACT != layout) {